'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.REACT_FORMCTRL = exports.REACT_FORMCTRL_NAME = undefined;
exports.onRegisterForm = onRegisterForm;
exports.onUnregisterForm = onUnregisterForm;
exports.onSubmitForm = onSubmitForm;
exports.onResetForm = onResetForm;
exports.onRegisterField = onRegisterField;
exports.onUnregisterField = onUnregisterField;
exports.onFieldPropsChanged = onFieldPropsChanged;
exports.onFieldChanged = onFieldChanged;
exports.onFieldBlur = onFieldBlur;
exports.onRegisterValidators = onRegisterValidators;
exports.onRegisterFieldArray = onRegisterFieldArray;
exports.onUnregisterFieldArray = onUnregisterFieldArray;
exports.onFieldArrayEntryPush = onFieldArrayEntryPush;
exports.onFieldArrayEntryRemove = onFieldArrayEntryRemove;

var _provider = require('./provider');

var _provider2 = require('./provider.utils');

var REACT_FORMCTRL_NAME = exports.REACT_FORMCTRL_NAME = 'react-formctl';

var REACT_FORMCTRL = exports.REACT_FORMCTRL = {
    EVENTS: {
        REGISTER_FORM: REACT_FORMCTRL_NAME + '.registerForm',
        UNREGISTER_FORM: REACT_FORMCTRL_NAME + '.unregisterForm',
        REGISTER_FIELD: REACT_FORMCTRL_NAME + '.registerField',
        UNREGISTER_FIELD: REACT_FORMCTRL_NAME + '.unregisterField',
        FORM_CHANGED: REACT_FORMCTRL_NAME + '.formChanged',
        FIELD_CHANGED: REACT_FORMCTRL_NAME + '.fieldChanged',
        FIELD_PROPS_CHANGED: REACT_FORMCTRL_NAME + '.fieldPropsChanged',
        FIELD_BLURRED: REACT_FORMCTRL_NAME + '.fieldBlurred',
        REGISTER_FIELD_ARRAY: REACT_FORMCTRL_NAME + '.registerFieldArray',
        UNREGISTER_FIELD_ARRAY: REACT_FORMCTRL_NAME + '.unregisterFieldArray',
        FIELD_ARRAY_CHANGED: REACT_FORMCTRL_NAME + '.fieldArrayChanged',
        PUSHED_FIELD_ENTRY: REACT_FORMCTRL_NAME + '.pushedFieldArray',
        REMOVED_FIELD_ENTRY: REACT_FORMCTRL_NAME + '.removedFieldArray',
        FORM_SUBMITED: REACT_FORMCTRL_NAME + '.formSubmited',
        FORM_RESETED: REACT_FORMCTRL_NAME + '.formReseted',
        REGISTER_VALIDATORS: REACT_FORMCTRL_NAME + '.registerValidators'
    }
};

function onRegisterForm(form) {
    return {
        type: REACT_FORMCTRL.EVENTS.REGISTER_FORM,
        payload: { form: form }
    };
}

function onUnregisterForm(form) {
    return {
        type: REACT_FORMCTRL.EVENTS.UNREGISTER_FORM,
        payload: { form: form }
    };
}

function onSubmitForm(form, formRef) {
    return {
        type: REACT_FORMCTRL.EVENTS.FORM_SUBMITED,
        payload: { form: form, formRef: formRef }
    };
}

function onResetForm(form) {
    return {
        type: REACT_FORMCTRL.EVENTS.FORM_RESETED,
        payload: { form: form }
    };
}

function onRegisterField(form, field, fieldCtrl) {
    return {
        type: REACT_FORMCTRL.EVENTS.REGISTER_FIELD,
        payload: { form: form, field: field, fieldCtrl: (0, _provider2.copyFieldCtrl)(fieldCtrl) }
    };
}

function onUnregisterField(form, field) {
    return {
        type: REACT_FORMCTRL.EVENTS.UNREGISTER_FIELD,
        payload: { form: form, field: field }
    };
}

function onFieldPropsChanged(form, field, props) {
    return {
        type: REACT_FORMCTRL.EVENTS.FIELD_PROPS_CHANGED,
        payload: { form: form, field: field, props: (0, _provider2.copyFieldCtrlProps)(props) }
    };
}

function onFieldChanged(form, field, value, files) {
    return {
        type: REACT_FORMCTRL.EVENTS.FIELD_CHANGED,
        payload: { form: form, field: field, value: value, files: (0, _provider2.copyFiles)(files) }
    };
}

function onFieldBlur(form, field) {
    return {
        type: REACT_FORMCTRL.EVENTS.FIELD_BLURRED,
        payload: { form: form, field: field }
    };
}

function onRegisterValidators(validators) {
    return {
        type: REACT_FORMCTRL.EVENTS.REGISTER_VALIDATORS,
        payload: { validators: validators }
    };
}

function onRegisterFieldArray(form, name, withEmptyEntry, initialValues) {
    return {
        type: REACT_FORMCTRL.EVENTS.REGISTER_FIELD_ARRAY,
        payload: { form: form, name: name, withEmptyEntry: withEmptyEntry, initialValues: initialValues }
    };
}

function onUnregisterFieldArray(form, name) {
    return {
        type: REACT_FORMCTRL.EVENTS.UNREGISTER_FIELD_ARRAY,
        payload: { form: form, name: name }
    };
}

function onFieldArrayEntryPush(form, name, initialValues) {
    return {
        type: REACT_FORMCTRL.EVENTS.PUSHED_FIELD_ENTRY,
        payload: { form: form, name: name, initialValues: initialValues }
    };
}

function onFieldArrayEntryRemove(form, name, index) {
    return {
        type: REACT_FORMCTRL.EVENTS.REMOVED_FIELD_ENTRY,
        payload: { form: form, name: name, index: index }
    };
}