'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.formProviderEffects = formProviderEffects;

var _provider = require('./provider.actions');

var _provider2 = require('./provider.utils');

function forwardEvent(eventName, detail) {
    var payload = { detail: detail };
    var event = new CustomEvent(eventName, payload);
    document.dispatchEvent(event);
}

function forwardSubmitFormEvent(state, payload) {
    var formName = payload.form;
    var formRef = payload.formRef;
    var formCtrl = state.forms[formName];
    if (formCtrl) {
        var values = formCtrl.values;
        forwardEvent(_provider.REACT_FORMCTRL.EVENTS.FORM_SUBMITED + '#' + formName, { values: values, formRef: formRef, formCtrl: (0, _provider2.copyFormCtrl)(formCtrl) });
    }
}

function forwardFieldChangedEvent(state, payload) {
    var form = payload.form;
    var field = payload.field;
    var formCtrl = state.forms[form];
    if (formCtrl) {
        var fieldCtrl = formCtrl.fields[field];
        forwardEvent(_provider.REACT_FORMCTRL.EVENTS.FIELD_CHANGED + '#' + form + '#' + field, { form: form, field: field, fieldCtrl: (0, _provider2.copyFieldCtrl)(fieldCtrl) });
    }
}

function forwardFormChangedEvent(state, payload) {
    var form = payload.form;
    var formCtrl = state.forms[form];
    if (formCtrl) {
        forwardEvent(_provider.REACT_FORMCTRL.EVENTS.FORM_CHANGED + '#' + form, { form: form, formCtrl: (0, _provider2.copyFormCtrl)(formCtrl) });
    }
}

function forwardFormResetEvent(state, payload) {
    var form = payload.form;
    var formCtrl = state.forms[form];
    if (formCtrl) {
        Object.keys(formCtrl.fields).forEach(function (field) {
            var fieldCtrl = formCtrl.fields[field];
            forwardEvent(_provider.REACT_FORMCTRL.EVENTS.FIELD_CHANGED + '#' + form + '#' + field, { form: form, field: field, fieldCtrl: (0, _provider2.copyFieldCtrl)(fieldCtrl) });
        });
    }
}

function formProviderEffects(state, action) {
    var EVENTS = _provider.REACT_FORMCTRL.EVENTS;
    var type = action.type;
    var payload = action.payload;
    switch (type) {
        case EVENTS.FIELD_BLURRED:
        case EVENTS.REGISTER_FIELD:
        case EVENTS.FIELD_CHANGED:
        case EVENTS.FIELD_PROPS_CHANGED:
            forwardFieldChangedEvent(state, payload);
            forwardFormChangedEvent(state, payload);
            break;

        case EVENTS.FORM_SUBMITED:
            forwardSubmitFormEvent(state, payload);
            break;
        case EVENTS.FORM_RESETED:
            forwardFormResetEvent(state, payload);
            forwardFormChangedEvent(state, payload);
            break;
        case EVENTS.REGISTER_FORM:
        case EVENTS.UNREGISTER_FORM:
        case EVENTS.UNREGISTER_FIELD:
        default:
            break;
    }
}